# Change Log

## 0.1.0 (2016-03-29)

Features

  - Added pycamv package, provides functionality for validating data sets.
  - Added pyproteome.bca module, provides functionality for processing BCA
    protein concentration measurements.
  - Added several new functions to pyproteome.analysis.
  - Added pyproteome.paths module for custom directory structures.

Bugfixes:

  - Fixed numerous py2 vs. py3 bugs.
  - Updated many module and function docstrings.
  - Added doc interlinks for function parameter types.

## 0.0.1 (2016-03-03)

Initial release
